# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/content/events.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.content import fragment_pb2 as eolymp_dot_content_dot_fragment__pb2
from eolymp.content import variant_pb2 as eolymp_dot_content_dot_variant__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1b\x65olymp/content/events.proto\x12\x0e\x65olymp.content\x1a\x1d\x65olymp/content/fragment.proto\x1a\x1c\x65olymp/content/variant.proto\"i\n\x14\x46ragmentChangedEvent\x12(\n\x06\x62\x65\x66ore\x18\x01 \x01(\x0b\x32\x18.eolymp.content.Fragment\x12\'\n\x05\x61\x66ter\x18\x02 \x01(\x0b\x32\x18.eolymp.content.Fragment\"\x92\x01\n\x13VariantChangedEvent\x12*\n\x08\x66ragment\x18\x03 \x01(\x0b\x32\x18.eolymp.content.Fragment\x12\'\n\x06\x62\x65\x66ore\x18\x01 \x01(\x0b\x32\x17.eolymp.content.Variant\x12&\n\x05\x61\x66ter\x18\x02 \x01(\x0b\x32\x17.eolymp.content.VariantB1Z/github.com/eolymp/go-sdk/eolymp/content;contentb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.content.events_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z/github.com/eolymp/go-sdk/eolymp/content;content'
  _FRAGMENTCHANGEDEVENT._serialized_start=108
  _FRAGMENTCHANGEDEVENT._serialized_end=213
  _VARIANTCHANGEDEVENT._serialized_start=216
  _VARIANTCHANGEDEVENT._serialized_end=362
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/course/enrollment_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.annotations import http_pb2 as eolymp_dot_annotations_dot_http__pb2
from eolymp.annotations import ratelimit_pb2 as eolymp_dot_annotations_dot_ratelimit__pb2
from eolymp.annotations import scope_pb2 as eolymp_dot_annotations_dot_scope__pb2
from eolymp.course import enrollment_pb2 as eolymp_dot_course_dot_enrollment__pb2
from eolymp.wellknown import direction_pb2 as eolymp_dot_wellknown_dot_direction__pb2
from eolymp.wellknown import expression_pb2 as eolymp_dot_wellknown_dot_expression__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n&eolymp/course/enrollment_service.proto\x12\reolymp.course\x1a\x1d\x65olymp/annotations/http.proto\x1a\"eolymp/annotations/ratelimit.proto\x1a\x1e\x65olymp/annotations/scope.proto\x1a\x1e\x65olymp/course/enrollment.proto\x1a eolymp/wellknown/direction.proto\x1a!eolymp/wellknown/expression.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"F\n\x15\x43reateEnrollmentInput\x12-\n\nenrollment\x18\x01 \x01(\x0b\x32\x19.eolymp.course.Enrollment\"/\n\x16\x43reateEnrollmentOutput\x12\x15\n\renrollment_id\x18\x01 \x01(\t\"\xe8\x01\n\x15UpdateEnrollmentInput\x12\x39\n\x05patch\x18\x01 \x03(\x0e\x32*.eolymp.course.UpdateEnrollmentInput.Patch\x12\x15\n\renrollment_id\x18\x02 \x01(\t\x12-\n\nenrollment\x18\x03 \x01(\x0b\x32\x19.eolymp.course.Enrollment\"N\n\x05Patch\x12\x07\n\x03\x41LL\x10\x00\x12\x0f\n\x0b\x41SSIGNMENTS\x10\x01\x12\x13\n\x0f\x41SSIGNMENTS_ADD\x10\x02\x12\x16\n\x12\x41SSIGNMENTS_REMOVE\x10\x03\"\x18\n\x16UpdateEnrollmentOutput\".\n\x15\x44\x65leteEnrollmentInput\x12\x15\n\renrollment_id\x18\x01 \x01(\t\"\x18\n\x16\x44\x65leteEnrollmentOutput\"\xbf\x03\n\x14ListEnrollmentsInput\x12\x0e\n\x06offset\x18\n \x01(\x05\x12\x0c\n\x04size\x18\x0b \x01(\x05\x12;\n\x07\x66ilters\x18( \x01(\x0b\x32*.eolymp.course.ListEnrollmentsInput.Filter\x12:\n\x04sort\x18\x32 \x01(\x0e\x32,.eolymp.course.ListEnrollmentsInput.Sortable\x12*\n\x05order\x18\x33 \x01(\x0e\x32\x1b.eolymp.wellknown.Direction\x12/\n\x05\x65xtra\x18\xe3\x08 \x03(\x0e\x32\x1f.eolymp.course.Enrollment.Extra\x1a\x99\x01\n\x06\x46ilter\x12*\n\x02id\x18\n \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12\x31\n\tmember_id\x18\x0b \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12\x30\n\x08group_id\x18\x0c \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\"\x17\n\x08Sortable\x12\x0b\n\x07\x44\x45\x46\x41ULT\x10\x00\"P\n\x15ListEnrollmentsOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12(\n\x05items\x18\x02 \x03(\x0b\x32\x19.eolymp.course.Enrollment\"a\n\x17\x44\x65scribeEnrollmentInput\x12\x15\n\renrollment_id\x18\x01 \x01(\t\x12/\n\x05\x65xtra\x18\xe3\x08 \x03(\x0e\x32\x1f.eolymp.course.Enrollment.Extra\"I\n\x18\x44\x65scribeEnrollmentOutput\x12-\n\nenrollment\x18\x01 \x01(\x0b\x32\x19.eolymp.course.Enrollment2\xee\x06\n\x11\x45nrollmentService\x12\x9f\x01\n\x10\x43reateEnrollment\x12$.eolymp.course.CreateEnrollmentInput\x1a%.eolymp.course.CreateEnrollmentOutput\">\x82\xe3\n\x17\x8a\xe3\n\x13\x63ourse:course:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02\x0e\x1a\x0c/enrollments\x12\xaf\x01\n\x10UpdateEnrollment\x12$.eolymp.course.UpdateEnrollmentInput\x1a%.eolymp.course.UpdateEnrollmentOutput\"N\x82\xe3\n\x17\x8a\xe3\n\x13\x63ourse:course:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02\x1e\x1a\x1c/enrollments/{enrollment_id}\x12\xaf\x01\n\x10\x44\x65leteEnrollment\x12$.eolymp.course.DeleteEnrollmentInput\x1a%.eolymp.course.DeleteEnrollmentOutput\"N\x82\xe3\n\x17\x8a\xe3\n\x13\x63ourse:course:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02\x1e*\x1c/enrollments/{enrollment_id}\x12\xb4\x01\n\x12\x44\x65scribeEnrollment\x12&.eolymp.course.DescribeEnrollmentInput\x1a\'.eolymp.course.DescribeEnrollmentOutput\"M\x82\xe3\n\x16\x8a\xe3\n\x12\x63ourse:course:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\nd\x82\xd3\xe4\x93\x02\x1e\x12\x1c/enrollments/{enrollment_id}\x12\x9b\x01\n\x0fListEnrollments\x12#.eolymp.course.ListEnrollmentsInput\x1a$.eolymp.course.ListEnrollmentsOutput\"=\x82\xe3\n\x16\x8a\xe3\n\x12\x63ourse:course:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\nd\x82\xd3\xe4\x93\x02\x0e\x12\x0c/enrollmentsB/Z-github.com/eolymp/go-sdk/eolymp/course;courseb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.course.enrollment_service_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z-github.com/eolymp/go-sdk/eolymp/course;course'
  _ENROLLMENTSERVICE.methods_by_name['CreateEnrollment']._options = None
  _ENROLLMENTSERVICE.methods_by_name['CreateEnrollment']._serialized_options = b'\202\343\n\027\212\343\n\023course:course:write\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\323\344\223\002\016\032\014/enrollments'
  _ENROLLMENTSERVICE.methods_by_name['UpdateEnrollment']._options = None
  _ENROLLMENTSERVICE.methods_by_name['UpdateEnrollment']._serialized_options = b'\202\343\n\027\212\343\n\023course:course:write\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\323\344\223\002\036\032\034/enrollments/{enrollment_id}'
  _ENROLLMENTSERVICE.methods_by_name['DeleteEnrollment']._options = None
  _ENROLLMENTSERVICE.methods_by_name['DeleteEnrollment']._serialized_options = b'\202\343\n\027\212\343\n\023course:course:write\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\323\344\223\002\036*\034/enrollments/{enrollment_id}'
  _ENROLLMENTSERVICE.methods_by_name['DescribeEnrollment']._options = None
  _ENROLLMENTSERVICE.methods_by_name['DescribeEnrollment']._serialized_options = b'\202\343\n\026\212\343\n\022course:course:read\352\342\n\013\365\342\n\000\000\240A\370\342\nd\202\323\344\223\002\036\022\034/enrollments/{enrollment_id}'
  _ENROLLMENTSERVICE.methods_by_name['ListEnrollments']._options = None
  _ENROLLMENTSERVICE.methods_by_name['ListEnrollments']._serialized_options = b'\202\343\n\026\212\343\n\022course:course:read\352\342\n\013\365\342\n\000\000\240A\370\342\nd\202\323\344\223\002\016\022\014/enrollments'
  _CREATEENROLLMENTINPUT._serialized_start=290
  _CREATEENROLLMENTINPUT._serialized_end=360
  _CREATEENROLLMENTOUTPUT._serialized_start=362
  _CREATEENROLLMENTOUTPUT._serialized_end=409
  _UPDATEENROLLMENTINPUT._serialized_start=412
  _UPDATEENROLLMENTINPUT._serialized_end=644
  _UPDATEENROLLMENTINPUT_PATCH._serialized_start=566
  _UPDATEENROLLMENTINPUT_PATCH._serialized_end=644
  _UPDATEENROLLMENTOUTPUT._serialized_start=646
  _UPDATEENROLLMENTOUTPUT._serialized_end=670
  _DELETEENROLLMENTINPUT._serialized_start=672
  _DELETEENROLLMENTINPUT._serialized_end=718
  _DELETEENROLLMENTOUTPUT._serialized_start=720
  _DELETEENROLLMENTOUTPUT._serialized_end=744
  _LISTENROLLMENTSINPUT._serialized_start=747
  _LISTENROLLMENTSINPUT._serialized_end=1194
  _LISTENROLLMENTSINPUT_FILTER._serialized_start=1016
  _LISTENROLLMENTSINPUT_FILTER._serialized_end=1169
  _LISTENROLLMENTSINPUT_SORTABLE._serialized_start=1171
  _LISTENROLLMENTSINPUT_SORTABLE._serialized_end=1194
  _LISTENROLLMENTSOUTPUT._serialized_start=1196
  _LISTENROLLMENTSOUTPUT._serialized_end=1276
  _DESCRIBEENROLLMENTINPUT._serialized_start=1278
  _DESCRIBEENROLLMENTINPUT._serialized_end=1375
  _DESCRIBEENROLLMENTOUTPUT._serialized_start=1377
  _DESCRIBEENROLLMENTOUTPUT._serialized_end=1450
  _ENROLLMENTSERVICE._serialized_start=1453
  _ENROLLMENTSERVICE._serialized_end=2331
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler. DO NOT EDIT!
# See https://github.com/eolymp/contracts/tree/main/cmd/protoc-gen-python-esdk for more details.
"""Generated protocol buffer code."""

import urllib.parse
from google.protobuf import symbol_database as _symbol_database

_sym_db = _symbol_database.Default()


class RatingServiceClient:
    def __init__(self, transport, url="https://api.eolymp.com"):
        self.transport = transport
        self.url = url

    def SetRating(self, request, **kwargs):
        path = "/rating"

        return self.transport.request(
            method="POST",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.rating.SetRatingOutput"),
            **kwargs,
        )

    def UpdateRating(self, request, **kwargs):
        path = "/rating/"+urllib.parse.quote(request.rating_id)

        # Cleanup URL parameters to avoid any ambiguity
        request.rating_id = ""

        return self.transport.request(
            method="PUT",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.rating.UpdateRatingOutput"),
            **kwargs,
        )

    def DeleteRating(self, request, **kwargs):
        path = "/rating/"+urllib.parse.quote(request.rating_id)

        # Cleanup URL parameters to avoid any ambiguity
        request.rating_id = ""

        return self.transport.request(
            method="DELETE",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.rating.DeleteRatingOutput"),
            **kwargs,
        )

    def DescribeRating(self, request, **kwargs):
        path = "/rating/"+urllib.parse.quote(request.rating_id)

        # Cleanup URL parameters to avoid any ambiguity
        request.rating_id = ""

        return self.transport.request(
            method="GET",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.rating.DescribeRatingOutput"),
            **kwargs,
        )

    def ListRating(self, request, **kwargs):
        path = "/members/"+urllib.parse.quote(request.member_id)+"/rating"

        # Cleanup URL parameters to avoid any ambiguity
        request.member_id = ""

        return self.transport.request(
            method="GET",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.rating.ListRatingOutput"),
            **kwargs,
        )

    def DescribeRatingBoundaries(self, request, **kwargs):
        path = "/rating-boundaries"

        return self.transport.request(
            method="GET",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.rating.DescribeRatingBoundariesOutput"),
            **kwargs,
        )

    def DescribeRatingDistribution(self, request, **kwargs):
        path = "/rating-distribution"

        return self.transport.request(
            method="GET",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.rating.DescribeRatingDistributionOutput"),
            **kwargs,
        )




from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Enrollment(_message.Message):
    __slots__ = ["assignments", "display_name", "enrolled_at", "expires_at", "group_id", "id", "member_id", "parent_id"]
    class Extra(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = []
    class Assignment(_message.Message):
        __slots__ = ["complete_before", "duration", "module_id", "start_after"]
        COMPLETE_BEFORE_FIELD_NUMBER: _ClassVar[int]
        DURATION_FIELD_NUMBER: _ClassVar[int]
        MODULE_ID_FIELD_NUMBER: _ClassVar[int]
        START_AFTER_FIELD_NUMBER: _ClassVar[int]
        complete_before: _timestamp_pb2.Timestamp
        duration: int
        module_id: str
        start_after: _timestamp_pb2.Timestamp
        def __init__(self, module_id: _Optional[str] = ..., start_after: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., complete_before: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., duration: _Optional[int] = ...) -> None: ...
    ASSIGNMENTS_FIELD_NUMBER: _ClassVar[int]
    DISPLAY_NAME_FIELD_NUMBER: _ClassVar[int]
    ENROLLED_AT_FIELD_NUMBER: _ClassVar[int]
    EXPIRES_AT_FIELD_NUMBER: _ClassVar[int]
    GROUP_ID_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    MEMBER_ID_FIELD_NUMBER: _ClassVar[int]
    PARENT_ID_FIELD_NUMBER: _ClassVar[int]
    UNKNOWN_EXTRA: Enrollment.Extra
    assignments: _containers.RepeatedCompositeFieldContainer[Enrollment.Assignment]
    display_name: str
    enrolled_at: _timestamp_pb2.Timestamp
    expires_at: _timestamp_pb2.Timestamp
    group_id: str
    id: str
    member_id: str
    parent_id: str
    def __init__(self, id: _Optional[str] = ..., parent_id: _Optional[str] = ..., display_name: _Optional[str] = ..., member_id: _Optional[str] = ..., group_id: _Optional[str] = ..., enrolled_at: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., expires_at: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., assignments: _Optional[_Iterable[_Union[Enrollment.Assignment, _Mapping]]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/course/enrollment.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1e\x65olymp/course/enrollment.proto\x12\reolymp.course\x1a\x1fgoogle/protobuf/timestamp.proto\"\xc8\x03\n\nEnrollment\x12\n\n\x02id\x18\x01 \x01(\t\x12\x11\n\tparent_id\x18\x02 \x01(\t\x12\x14\n\x0c\x64isplay_name\x18\x03 \x01(\t\x12\x13\n\tmember_id\x18\n \x01(\tH\x00\x12\x12\n\x08group_id\x18\x0b \x01(\tH\x00\x12/\n\x0b\x65nrolled_at\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\nexpires_at\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x39\n\x0b\x61ssignments\x18\x15 \x03(\x0b\x32$.eolymp.course.Enrollment.Assignment\x1a\x97\x01\n\nAssignment\x12\x11\n\tmodule_id\x18\x01 \x01(\t\x12/\n\x0bstart_after\x18\n \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x33\n\x0f\x63omplete_before\x18\x0b \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x10\n\x08\x64uration\x18\x14 \x01(\r\"\x1a\n\x05\x45xtra\x12\x11\n\rUNKNOWN_EXTRA\x10\x00\x42\n\n\x08\x61ssigneeB/Z-github.com/eolymp/go-sdk/eolymp/course;courseb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.course.enrollment_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z-github.com/eolymp/go-sdk/eolymp/course;course'
  _ENROLLMENT._serialized_start=83
  _ENROLLMENT._serialized_end=539
  _ENROLLMENT_ASSIGNMENT._serialized_start=348
  _ENROLLMENT_ASSIGNMENT._serialized_end=499
  _ENROLLMENT_EXTRA._serialized_start=501
  _ENROLLMENT_EXTRA._serialized_end=527
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler. DO NOT EDIT!
# See https://github.com/eolymp/contracts/tree/main/cmd/protoc-gen-python-esdk for more details.
"""Generated protocol buffer code."""

import urllib.parse
from google.protobuf import symbol_database as _symbol_database

_sym_db = _symbol_database.Default()


class EntryServiceClient:
    def __init__(self, transport, url="https://api.eolymp.com"):
        self.transport = transport
        self.url = url

    def CreateEntry(self, request, **kwargs):
        path = "/entries"

        return self.transport.request(
            method="POST",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.course.CreateEntryOutput"),
            **kwargs,
        )

    def UpdateEntry(self, request, **kwargs):
        path = "/entries/"+urllib.parse.quote(request.entry_id)

        # Cleanup URL parameters to avoid any ambiguity
        request.entry_id = ""

        return self.transport.request(
            method="PUT",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.course.UpdateEntryOutput"),
            **kwargs,
        )

    def RenameEntry(self, request, **kwargs):
        path = "/entries/"+urllib.parse.quote(request.entry_id)+"/title"

        # Cleanup URL parameters to avoid any ambiguity
        request.entry_id = ""

        return self.transport.request(
            method="PUT",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.course.RenameEntryOutput"),
            **kwargs,
        )

    def MoveEntry(self, request, **kwargs):
        path = "/entries/"+urllib.parse.quote(request.entry_id)+"/position"

        # Cleanup URL parameters to avoid any ambiguity
        request.entry_id = ""

        return self.transport.request(
            method="PUT",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.course.MoveEntryOutput"),
            **kwargs,
        )

    def DeleteEntry(self, request, **kwargs):
        path = "/entries/"+urllib.parse.quote(request.entry_id)

        # Cleanup URL parameters to avoid any ambiguity
        request.entry_id = ""

        return self.transport.request(
            method="DELETE",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.course.DeleteEntryOutput"),
            **kwargs,
        )

    def DescribeEntry(self, request, **kwargs):
        path = "/entries/"+urllib.parse.quote(request.entry_id)

        # Cleanup URL parameters to avoid any ambiguity
        request.entry_id = ""

        return self.transport.request(
            method="GET",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.course.DescribeEntryOutput"),
            **kwargs,
        )

    def ListEntries(self, request, **kwargs):
        path = "/entries"

        return self.transport.request(
            method="GET",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.course.ListEntriesOutput"),
            **kwargs,
        )

    def DescribeTree(self, request, **kwargs):
        path = "/toc"

        return self.transport.request(
            method="GET",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.course.DescribeTreeOutput"),
            **kwargs,
        )

    def ListParents(self, request, **kwargs):
        path = "/entries/"+urllib.parse.quote(request.entry_id)+"/parents"

        # Cleanup URL parameters to avoid any ambiguity
        request.entry_id = ""

        return self.transport.request(
            method="GET",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.course.ListParentsOutput"),
            **kwargs,
        )




from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Assignment(_message.Message):
    __slots__ = ["complete_before", "completed_at", "created_at", "duration", "group_id", "id", "items", "member_id", "start_after", "started_at", "status"]
    class Extra(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = []
    class Status(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = []
    class Item(_message.Message):
        __slots__ = ["item_id", "module_id"]
        ITEM_ID_FIELD_NUMBER: _ClassVar[int]
        MODULE_ID_FIELD_NUMBER: _ClassVar[int]
        item_id: str
        module_id: str
        def __init__(self, module_id: _Optional[str] = ..., item_id: _Optional[str] = ...) -> None: ...
    ACTIVE: Assignment.Status
    COMPLETE: Assignment.Status
    COMPLETED_AT_FIELD_NUMBER: _ClassVar[int]
    COMPLETE_BEFORE_FIELD_NUMBER: _ClassVar[int]
    CREATED_AT_FIELD_NUMBER: _ClassVar[int]
    DURATION_FIELD_NUMBER: _ClassVar[int]
    GROUP_ID_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    ITEMS_FIELD_NUMBER: _ClassVar[int]
    MEMBER_ID_FIELD_NUMBER: _ClassVar[int]
    READY: Assignment.Status
    SCHEDULED: Assignment.Status
    STARTED_AT_FIELD_NUMBER: _ClassVar[int]
    START_AFTER_FIELD_NUMBER: _ClassVar[int]
    STATUS_FIELD_NUMBER: _ClassVar[int]
    UNASSIGNED: Assignment.Status
    UNKNOWN_EXTRA: Assignment.Extra
    UNKNOWN_STATUS: Assignment.Status
    UPSOLVE: Assignment.Status
    complete_before: _timestamp_pb2.Timestamp
    completed_at: _timestamp_pb2.Timestamp
    created_at: _timestamp_pb2.Timestamp
    duration: int
    group_id: str
    id: str
    items: _containers.RepeatedCompositeFieldContainer[Assignment.Item]
    member_id: str
    start_after: _timestamp_pb2.Timestamp
    started_at: _timestamp_pb2.Timestamp
    status: Assignment.Status
    def __init__(self, id: _Optional[str] = ..., member_id: _Optional[str] = ..., group_id: _Optional[str] = ..., status: _Optional[_Union[Assignment.Status, str]] = ..., start_after: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., complete_before: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., duration: _Optional[int] = ..., items: _Optional[_Iterable[_Union[Assignment.Item, _Mapping]]] = ..., created_at: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., started_at: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., completed_at: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ...) -> None: ...



from eolymp.annotations import http_pb2 as _http_pb2
from eolymp.annotations import ratelimit_pb2 as _ratelimit_pb2
from eolymp.annotations import scope_pb2 as _scope_pb2
from eolymp.course import enrollment_pb2 as _enrollment_pb2
from eolymp.wellknown import direction_pb2 as _direction_pb2
from eolymp.wellknown import expression_pb2 as _expression_pb2
from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class CreateEnrollmentInput(_message.Message):
    __slots__ = ["enrollment"]
    ENROLLMENT_FIELD_NUMBER: _ClassVar[int]
    enrollment: _enrollment_pb2.Enrollment
    def __init__(self, enrollment: _Optional[_Union[_enrollment_pb2.Enrollment, _Mapping]] = ...) -> None: ...

class CreateEnrollmentOutput(_message.Message):
    __slots__ = ["enrollment_id"]
    ENROLLMENT_ID_FIELD_NUMBER: _ClassVar[int]
    enrollment_id: str
    def __init__(self, enrollment_id: _Optional[str] = ...) -> None: ...

class DeleteEnrollmentInput(_message.Message):
    __slots__ = ["enrollment_id"]
    ENROLLMENT_ID_FIELD_NUMBER: _ClassVar[int]
    enrollment_id: str
    def __init__(self, enrollment_id: _Optional[str] = ...) -> None: ...

class DeleteEnrollmentOutput(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class DescribeEnrollmentInput(_message.Message):
    __slots__ = ["enrollment_id", "extra"]
    ENROLLMENT_ID_FIELD_NUMBER: _ClassVar[int]
    EXTRA_FIELD_NUMBER: _ClassVar[int]
    enrollment_id: str
    extra: _containers.RepeatedScalarFieldContainer[_enrollment_pb2.Enrollment.Extra]
    def __init__(self, enrollment_id: _Optional[str] = ..., extra: _Optional[_Iterable[_Union[_enrollment_pb2.Enrollment.Extra, str]]] = ...) -> None: ...

class DescribeEnrollmentOutput(_message.Message):
    __slots__ = ["enrollment"]
    ENROLLMENT_FIELD_NUMBER: _ClassVar[int]
    enrollment: _enrollment_pb2.Enrollment
    def __init__(self, enrollment: _Optional[_Union[_enrollment_pb2.Enrollment, _Mapping]] = ...) -> None: ...

class ListEnrollmentsInput(_message.Message):
    __slots__ = ["extra", "filters", "offset", "order", "size", "sort"]
    class Sortable(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = []
    class Filter(_message.Message):
        __slots__ = ["group_id", "id", "member_id"]
        GROUP_ID_FIELD_NUMBER: _ClassVar[int]
        ID_FIELD_NUMBER: _ClassVar[int]
        MEMBER_ID_FIELD_NUMBER: _ClassVar[int]
        group_id: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionID]
        id: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionID]
        member_id: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionID]
        def __init__(self, id: _Optional[_Iterable[_Union[_expression_pb2.ExpressionID, _Mapping]]] = ..., member_id: _Optional[_Iterable[_Union[_expression_pb2.ExpressionID, _Mapping]]] = ..., group_id: _Optional[_Iterable[_Union[_expression_pb2.ExpressionID, _Mapping]]] = ...) -> None: ...
    DEFAULT: ListEnrollmentsInput.Sortable
    EXTRA_FIELD_NUMBER: _ClassVar[int]
    FILTERS_FIELD_NUMBER: _ClassVar[int]
    OFFSET_FIELD_NUMBER: _ClassVar[int]
    ORDER_FIELD_NUMBER: _ClassVar[int]
    SIZE_FIELD_NUMBER: _ClassVar[int]
    SORT_FIELD_NUMBER: _ClassVar[int]
    extra: _containers.RepeatedScalarFieldContainer[_enrollment_pb2.Enrollment.Extra]
    filters: ListEnrollmentsInput.Filter
    offset: int
    order: _direction_pb2.Direction
    size: int
    sort: ListEnrollmentsInput.Sortable
    def __init__(self, offset: _Optional[int] = ..., size: _Optional[int] = ..., filters: _Optional[_Union[ListEnrollmentsInput.Filter, _Mapping]] = ..., sort: _Optional[_Union[ListEnrollmentsInput.Sortable, str]] = ..., order: _Optional[_Union[_direction_pb2.Direction, str]] = ..., extra: _Optional[_Iterable[_Union[_enrollment_pb2.Enrollment.Extra, str]]] = ...) -> None: ...

class ListEnrollmentsOutput(_message.Message):
    __slots__ = ["items", "total"]
    ITEMS_FIELD_NUMBER: _ClassVar[int]
    TOTAL_FIELD_NUMBER: _ClassVar[int]
    items: _containers.RepeatedCompositeFieldContainer[_enrollment_pb2.Enrollment]
    total: int
    def __init__(self, total: _Optional[int] = ..., items: _Optional[_Iterable[_Union[_enrollment_pb2.Enrollment, _Mapping]]] = ...) -> None: ...

class UpdateEnrollmentInput(_message.Message):
    __slots__ = ["enrollment", "enrollment_id", "patch"]
    class Patch(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = []
    ALL: UpdateEnrollmentInput.Patch
    ASSIGNMENTS: UpdateEnrollmentInput.Patch
    ASSIGNMENTS_ADD: UpdateEnrollmentInput.Patch
    ASSIGNMENTS_REMOVE: UpdateEnrollmentInput.Patch
    ENROLLMENT_FIELD_NUMBER: _ClassVar[int]
    ENROLLMENT_ID_FIELD_NUMBER: _ClassVar[int]
    PATCH_FIELD_NUMBER: _ClassVar[int]
    enrollment: _enrollment_pb2.Enrollment
    enrollment_id: str
    patch: _containers.RepeatedScalarFieldContainer[UpdateEnrollmentInput.Patch]
    def __init__(self, patch: _Optional[_Iterable[_Union[UpdateEnrollmentInput.Patch, str]]] = ..., enrollment_id: _Optional[str] = ..., enrollment: _Optional[_Union[_enrollment_pb2.Enrollment, _Mapping]] = ...) -> None: ...

class UpdateEnrollmentOutput(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/course/module.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.ecm import content_pb2 as eolymp_dot_ecm_dot_content__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1a\x65olymp/course/module.proto\x12\reolymp.course\x1a\x18\x65olymp/ecm/content.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\xaa\x02\n\x06Module\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0b\n\x03url\x18\x02 \x01(\t\x12\r\n\x05\x64raft\x18\x03 \x01(\x08\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x11\n\timage_url\x18\x05 \x01(\t\x12\r\n\x05index\x18\x06 \x01(\r\x12(\n\x0b\x64\x65scription\x18\n \x01(\x0b\x32\x13.eolymp.ecm.Content\"I\n\x05\x45xtra\x12\x11\n\rUNKNOWN_EXTRA\x10\x00\x12\x15\n\x11\x44\x45SCRIPTION_VALUE\x10\x01\x12\x16\n\x12\x44\x45SCRIPTION_RENDER\x10\x02\"S\n\x06Status\x12\x12\n\x0eUNKNOWN_STATUS\x10\x00\x12\x0b\n\x07\x42LOCKED\x10\x01\x12\t\n\x05READY\x10\x02\x12\x0f\n\x0bIN_PROGRESS\x10\x03\x12\x0c\n\x08\x43OMPLETE\x10\x04\x42/Z-github.com/eolymp/go-sdk/eolymp/course;courseb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.course.module_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z-github.com/eolymp/go-sdk/eolymp/course;course'
  _MODULE._serialized_start=105
  _MODULE._serialized_end=403
  _MODULE_EXTRA._serialized_start=245
  _MODULE_EXTRA._serialized_end=318
  _MODULE_STATUS._serialized_start=320
  _MODULE_STATUS._serialized_end=403
# @@protoc_insertion_point(module_scope)
